@@ -56,10 +56,16 @@ patrick::with_parameters_test_that("Unit tests for tuning of PLR:",
         y_col = "y",
         d_cols = c("d1", "d2"), x_cols = Xnames)
     }
+    if (score == "IV-type") {
+      ml_g = learner
+    } else {
+      ml_g = NULL
+    }
     double_mlplr_obj_tuned = DoubleMLPLR$new(data_ml,
       n_folds = n_folds,
-      ml_g = learner,
+      ml_l = learner,
       ml_m = m_learner,
+      ml_g = ml_g,
       dml_procedure = dml_procedure,
       score = score,
       n_rep = n_rep)
@@ -73,12 +79,18 @@ patrick::with_parameters_test_that("Unit tests for tuning of PLR:",
       resolution = 5)
 
     param_grid = list(
-      "ml_g" = paradox::ParamSet$new(list(
-        paradox::ParamDbl$new("cp", lower = 0.01, upper = 0.02),
+      "ml_l" = paradox::ParamSet$new(list(
+        paradox::ParamDbl$new("cp", lower = 0.02, upper = 0.03),
         paradox::ParamInt$new("minsplit", lower = 1, upper = 2))),
       "ml_m" = paradox::ParamSet$new(list(
-        paradox::ParamDbl$new("cp", lower = 0.01, upper = 0.02),
-        paradox::ParamInt$new("minsplit", lower = 1, upper = 2))))
+        paradox::ParamDbl$new("cp", lower = 0.03, upper = 0.04),
+        paradox::ParamInt$new("minsplit", lower = 2, upper = 3))))
+
+    if (score == "IV-type") {
+      param_grid[["ml_g"]] = paradox::ParamSet$new(list(
+        paradox::ParamDbl$new("cp", lower = 0.015, upper = 0.025),
+        paradox::ParamInt$new("minsplit", lower = 3, upper = 4)))
+    }
 
     double_mlplr_obj_tuned$tune(param_set = param_grid, tune_on_folds = tune_on_folds, tune_settings = tune_sets)
 
